@@ -752,13 +752,13 @@ class DiffConfig:
 
         if self._dump_diff:
             print("=> differences - remove:",
-                  yaml.dump(remove_cfg, default_flow_style=False),
+                  yaml.dump(dict(remove_cfg), default_flow_style=False),
 
                   "=> differences - remove full:",
-                  yaml.dump(remove_cfg_full, default_flow_style=False),
+                  yaml.dump(dict(remove_cfg_full), default_flow_style=False),
 
                   "=> differences - update (add/change):",
-                  yaml.dump(update_cfg, default_flow_style=False),
+                  yaml.dump(dict(update_cfg), default_flow_style=False),
 
                   sep="\n")
 
