@@ -17,6 +17,7 @@ produces a delta configuration.
 
 
 import re
+import sys
 
 import netaddr
 
@@ -137,7 +138,6 @@ class _Cvt_Int_CDPEna(_CvtContext_Int):
         return "interface " + int_name, " cdp enable"
 
     def update(self, old, upd, new, int_name):
-        name, = args
         return ("interface " + int_name,
                 " " + ("" if upd else "no ") + "cdp enable")
 
@@ -543,6 +543,64 @@ class _Cvt_Int_StandbyVer(_CvtContext_Int):
 _cvts.append(_Cvt_Int_StandbyVer)
 
 
+class _Cvt_Int_StormCtrl(_CvtContext_Int):
+    cmd = "storm-control", None
+
+    def remove(self, old, rem, int_name, traffic):
+        return ("interface " + int_name,
+                " no storm-control %s level" % traffic)
+
+    def update(self, old, upd, new, int_name, traffic):
+        return ("interface " + int_name,
+                " storm-control %s level %.2f" % (traffic, upd))
+
+_cvts.append(_Cvt_Int_StormCtrl)
+
+
+class _Cvt_Int_SwPort(_CvtContext_Int):
+    cmd = "switchport",
+
+    def remove(self, old, rem, int_name):
+        # if the 'switchport' option is not present, that doesn't mean
+        # it's disabled but just that it's not specified, so we assume
+        # the default is for it to be disabled
+        #
+        # TODO: this is the case for routers (which we're concerned
+        # about here) but not switches: we'd probably need a separate
+        # platform for this
+        return "interface " + int_name, " no switchport"
+
+    def update(self, old, upd, new, int_name):
+        return ("interface " + int_name,
+                " " + ("" if upd else "no ") + "switchport")
+
+_cvts.append(_Cvt_Int_SwPort)
+
+
+class _Cvt_Int_SwPortMode(_CvtContext_Int):
+    cmd = "switchport-mode",
+
+    def remove(self, old, rem, int_name):
+        return "interface " + int_name, " no switchport mode"
+
+    def update(self, old, upd, new, int_name):
+        return "interface " + int_name, " switchport mode " + upd
+
+_cvts.append(_Cvt_Int_SwPortMode)
+
+
+class _Cvt_Int_SwPortNoNeg(_CvtContext_Int):
+    cmd = "switchport-nonegotiate",
+
+    def remove(self, old, rem, int_name):
+        return "interface " + int_name, " no switchport nonegotiate"
+
+    def update(self, old, upd, new, int_name):
+        return "interface " + int_name, " switchport nonegotiate"
+
+_cvts.append(_Cvt_Int_SwPortNoNeg)
+
+
 class _Cvt_Int_SwPortTrkNtv(_CvtContext_Int):
     # we just match the interface as we need to look inside it to see if
     # the interface is part of a channel group
@@ -684,7 +742,7 @@ class _Cvt_IPPfxList(DiffConvert):
         return "no ip prefix-list " + pfx_name
 
     def update(self, old, upd, new, pfx_name):
-        return explain_diffs(old, new, prefix="ip prefix-list " + pfx_name)
+        return explain_diffs(old, new, prefix="ip prefix-list %s " % pfx_name)
 
 _cvts.append(_Cvt_IPPfxList)
 
@@ -696,7 +754,8 @@ class _Cvt_IPv6PfxList(DiffConvert):
         return "no ipv6 prefix-list " + pfx_name
 
     def update(self, old, upd, new, pfx_name):
-        return explain_diffs(old, new, prefix="ipv6 prefix-list " + pfx_name)
+        return explain_diffs(
+                   old, new, prefix="ipv6 prefix-list %s " % pfx_name)
 
 _cvts.append(_Cvt_IPv6PfxList)
 
@@ -824,10 +883,16 @@ class _Cvt_Track_Obj(_CvtContext_Track):
     cmd = "object",
 
     def remove(self, old, rem, obj):
-        return "track %d" % obj, " no object " + rem
+        l = ["track %d" % obj]
+        for obj in rem:
+            l.append(" no object " + obj)
+        return l
 
     def update(self, old, upd, new, obj):
-        return "track %d" % obj, " object " + upd
+        l = ["track %d" % obj]
+        for obj in upd:
+            l.append(" object " + obj)
+        return l
 
 _cvts.append(_Cvt_Track_Obj)
 
@@ -878,7 +943,13 @@ class CiscoIOSDiffConfig(DiffConfig):
         "This method adds the converters for Cisco IOS."
 
         for cvt_class in _cvts:
-            self._add_converter(cvt_class())
+            try:
+                self._add_converter(cvt_class())
+            except:
+                print("with: cvt_class=" + repr(cvt_class),
+                      file=sys.stderr)
+
+                raise
 
 
     def _explain_comment(self, path):
